<?php

namespace Drupal\jmol\Element;
use Drupal\Core\Render\Element\RenderElement;

/**
 * Provides a jmol render element.
 *
 * @RenderElement("jmol")
 */
class Jmol extends RenderElement {

  /**
   * Define the available options for our new render element.
   */
  public function getInfo() {
    $class = get_class($this);


    // Produce the default settings for our render element.
    return [
      '#pre_render' => [
        [$class, 'preRenderJmol'],
      ],
      '#version' => NULL,
      '#theme' => $theme,
      '#id' => 'mydiv',
      '#info' => [
      ],
      '#attached' => [
        'library' => $library,
      ],
    ];
  }

  /**
   * Before rendering, we will add the appropriate libraries, and add
   * the necessary variables to drupalSettings so that the JS can access them.
   */
  public static function preRenderJmol($element) {
    // Examine the config file to see which library version to use.
    $config = \Drupal::config('jmol.settings');
    $version = $config->get('version');
    // Look at the element to see which version the user would like to use.
    // They may have changed it from the default.
    if ($element['#version'] != NULL) {
      $version = $element['#version'];
    }
    
    // The twig template to use
    $theme = "";

    // The javascript files to use.
    $library = '';
    if ($version == 'full') {
      $theme = 'jmol_template';
      $library = 'jmol/jmol';
    }
    elseif ($version == 'lite') {
      $theme = 'jmol_lite_template';
      $library = 'jmol/jmol_lite';
    }
    $element['#theme'] = $theme;

    // The full version requires the j2s directory. 
    if ($version == 'full') {
      $file_path = '/' . drupal_get_path('module', 'jmol') . '/lib/j2s';
      $element['#info']['j2sPath'] = $file_path;
    }

    // Add the info array to drupalSetting so the JS can access it.
    $id = $element['#id'];
    $drupalsettings['jmol'][$id] = [
      'info' => $element['#info'],
    ]; 
    $element['#attached'] = [
      'drupalSettings' => $drupalsettings,
      'library' => [$library],
    ];

    return $element;
  }
}
